==> cdktf_cdktf_provider_azurerm-7.0.1-py3-none-any.whl: package/lib/data-azurerm-private-endpoint-connection/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermPrivateEndpointConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection#id DataAzurermPrivateEndpointConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection#name DataAzurermPrivateEndpointConnection#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection#resource_group_name DataAzurermPrivateEndpointConnection#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection#timeouts DataAzurermPrivateEndpointConnection#timeouts}
    */
    readonly timeouts?: DataAzurermPrivateEndpointConnectionTimeouts;
}
export interface DataAzurermPrivateEndpointConnectionNetworkInterface {
}
export declare function dataAzurermPrivateEndpointConnectionNetworkInterfaceToTerraform(struct?: DataAzurermPrivateEndpointConnectionNetworkInterface): any;
export declare class DataAzurermPrivateEndpointConnectionNetworkInterfaceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAzurermPrivateEndpointConnectionNetworkInterface | undefined;
    set internalValue(value: DataAzurermPrivateEndpointConnectionNetworkInterface | undefined);
    get id(): string;
    get name(): string;
}
export declare class DataAzurermPrivateEndpointConnectionNetworkInterfaceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAzurermPrivateEndpointConnectionNetworkInterfaceOutputReference;
}
export interface DataAzurermPrivateEndpointConnectionPrivateServiceConnection {
}
export declare function dataAzurermPrivateEndpointConnectionPrivateServiceConnectionToTerraform(struct?: DataAzurermPrivateEndpointConnectionPrivateServiceConnection): any;
export declare class DataAzurermPrivateEndpointConnectionPrivateServiceConnectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAzurermPrivateEndpointConnectionPrivateServiceConnection | undefined;
    set internalValue(value: DataAzurermPrivateEndpointConnectionPrivateServiceConnection | undefined);
    get name(): string;
    get privateIpAddress(): string;
    get requestResponse(): string;
    get status(): string;
}
export declare class DataAzurermPrivateEndpointConnectionPrivateServiceConnectionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAzurermPrivateEndpointConnectionPrivateServiceConnectionOutputReference;
}
export interface DataAzurermPrivateEndpointConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection#read DataAzurermPrivateEndpointConnection#read}
    */
    readonly read?: string;
}
export declare function dataAzurermPrivateEndpointConnectionTimeoutsToTerraform(struct?: DataAzurermPrivateEndpointConnectionTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermPrivateEndpointConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermPrivateEndpointConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermPrivateEndpointConnectionTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection azurerm_private_endpoint_connection}
*/
export declare class DataAzurermPrivateEndpointConnection extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_private_endpoint_connection";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_endpoint_connection azurerm_private_endpoint_connection} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermPrivateEndpointConnectionConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermPrivateEndpointConnectionConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkInterface;
    get networkInterface(): DataAzurermPrivateEndpointConnectionNetworkInterfaceList;
    private _privateServiceConnection;
    get privateServiceConnection(): DataAzurermPrivateEndpointConnectionPrivateServiceConnectionList;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _timeouts;
    get timeouts(): DataAzurermPrivateEndpointConnectionTimeoutsOutputReference;
    putTimeouts(value: DataAzurermPrivateEndpointConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermPrivateEndpointConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-7.0.10-py3-none-any.whl: package/lib/data-azurerm-private-endpoint-connection/index.d.ts <==
/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermPrivateEndpointConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection#id DataAzurermPrivateEndpointConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection#name DataAzurermPrivateEndpointConnection#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection#resource_group_name DataAzurermPrivateEndpointConnection#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection#timeouts DataAzurermPrivateEndpointConnection#timeouts}
    */
    readonly timeouts?: DataAzurermPrivateEndpointConnectionTimeouts;
}
export interface DataAzurermPrivateEndpointConnectionNetworkInterface {
}
export declare function dataAzurermPrivateEndpointConnectionNetworkInterfaceToTerraform(struct?: DataAzurermPrivateEndpointConnectionNetworkInterface): any;
export declare class DataAzurermPrivateEndpointConnectionNetworkInterfaceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAzurermPrivateEndpointConnectionNetworkInterface | undefined;
    set internalValue(value: DataAzurermPrivateEndpointConnectionNetworkInterface | undefined);
    get id(): string;
    get name(): string;
}
export declare class DataAzurermPrivateEndpointConnectionNetworkInterfaceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAzurermPrivateEndpointConnectionNetworkInterfaceOutputReference;
}
export interface DataAzurermPrivateEndpointConnectionPrivateServiceConnection {
}
export declare function dataAzurermPrivateEndpointConnectionPrivateServiceConnectionToTerraform(struct?: DataAzurermPrivateEndpointConnectionPrivateServiceConnection): any;
export declare class DataAzurermPrivateEndpointConnectionPrivateServiceConnectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAzurermPrivateEndpointConnectionPrivateServiceConnection | undefined;
    set internalValue(value: DataAzurermPrivateEndpointConnectionPrivateServiceConnection | undefined);
    get name(): string;
    get privateIpAddress(): string;
    get requestResponse(): string;
    get status(): string;
}
export declare class DataAzurermPrivateEndpointConnectionPrivateServiceConnectionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAzurermPrivateEndpointConnectionPrivateServiceConnectionOutputReference;
}
export interface DataAzurermPrivateEndpointConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection#read DataAzurermPrivateEndpointConnection#read}
    */
    readonly read?: string;
}
export declare function dataAzurermPrivateEndpointConnectionTimeoutsToTerraform(struct?: DataAzurermPrivateEndpointConnectionTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermPrivateEndpointConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermPrivateEndpointConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermPrivateEndpointConnectionTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection azurerm_private_endpoint_connection}
*/
export declare class DataAzurermPrivateEndpointConnection extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_private_endpoint_connection";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.61.0/docs/data-sources/private_endpoint_connection azurerm_private_endpoint_connection} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermPrivateEndpointConnectionConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermPrivateEndpointConnectionConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkInterface;
    get networkInterface(): DataAzurermPrivateEndpointConnectionNetworkInterfaceList;
    private _privateServiceConnection;
    get privateServiceConnection(): DataAzurermPrivateEndpointConnectionPrivateServiceConnectionList;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _timeouts;
    get timeouts(): DataAzurermPrivateEndpointConnectionTimeoutsOutputReference;
    putTimeouts(value: DataAzurermPrivateEndpointConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermPrivateEndpointConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
